==> basscss-4.2.1.tgz: package/README.md <==
# Basscss

Low-level CSS toolkit

http://basscss.com

---

## Modular CSS toolkit based on OOCSS principles

Basscss is a lightweight collection of base element styles, utilities, layout modules, and color styles designed for speed, performance, and scalability.

## Features

### Designed for Design
With simple, humanized naming conventions,
Basscss is quick to internalize and easy to wrap your head around,
while striking a balance between consistency and flexibility.

### Responsive by Default
The web is inherently flexible, Basscss doesn't break that tradition
and provides lightweight solutions to design for all devices.

### Unobtrusive
Basscss doesn't dictate what your site should look like.
With extensible base styles and variables for typography, white space, breakpoints, and UI elements,
customizing the look and feel is easy.

### Mix and Match
With modular styles that work like building blocks,
Basscss provides a foundation of reusable and inter-operable styles
for greater freedom when designing in the browser.

Learn more at http://basscss.com

## Getting Started
Download or install Basscss from one of these sources:

```
git clone https://github.com/jxnblk/basscss.git
```

```
npm install basscss
```

```
bower install basscss
```

CDN:
```
<link src="http://d2v52k3cl9vedd.cloudfront.net/basscss/4.1.2/basscss.min.css" rel="stylesheet">
```

---

## Folder Structure
- `src`: Uncompiled Rework CSS source files
- `css`: Compiled CSS files
- `scss`: Compiled Sass partials
- `tasks`: Files for Gulp build process
- `docs`: Files for http://basscss.com site


## Documentation
View the full documentation with inline examples:

http://basscss.com/docs

### Guide to Web Design Basics
http://basscss.com/docs/guide

### Design Principles
http://basscss.com/docs/principles

---

[MIT license](http://opensource.org/licenses/MIT)

==> basscss-5.2.0.tgz: package/README.md <==
# Basscss

Low-level CSS toolkit

http://basscss.com

---

## Lightning-Fast Modular CSS

Basscss is a lightweight collection of base element styles, immutable utilities, layout modules, and color styles designed for speed, performance, and scalability.

## Features

### Designed for Design
With simple, humanized naming conventions,
Basscss is quick to internalize and easy to wrap your head around,
while striking a balance between consistency and flexibility.

### Responsive by Default
The web is inherently flexible, Basscss doesn't break that tradition
and provides lightweight solutions to design for all devices.

### Unobtrusive
Basscss doesn't dictate what your site should look like.
With extensible base styles and variables for typography, white space, breakpoints, and UI elements,
customizing the look and feel is easy.

### Mix and Match
With modular styles that work like building blocks,
Basscss provides a foundation of reusable and inter-operable styles
for greater freedom when designing in the browser.

## Getting Started

http://basscss.com/docs/getting-started

---

## Folder Structure
- `src`: CSS4 source files
- `css`: Processed CSS files for browser compatibility
- `scss`: Sass partials converted from CSS4 syntax
- `scripts`: Compilation and build scripts
- `docs`: Files for http://basscss.com site


## Documentation
View the full documentation with inline examples:

http://basscss.com/docs

### Guides
http://basscss.com/docs/guides

### Design Principles
http://basscss.com/docs/principles

### Examples
http://basscss.com/docs/showcase

---

[MIT license](http://opensource.org/licenses/MIT)
